@@ -8,6 +8,7 @@ from .constantscore import *
 from .customscore import *
 from .field import *
 from .filtered import *
+from .functionscore import *
 from .fuzzy import *
 from .fuzzylikethis import *
 from .haschild import *
@@ -23,6 +24,7 @@ from .query import *
 from .querystring import *
 from .range import *
 from .simple import *
+from .simplequerystring import SimpleQueryString
 from .term import *
 from .terms import *
 from .text import *
